==> QuACN_1.3.4.tar.gz: QuACN/R/getLabels.R <==
getLabels <- function(l){
  return(.labels[[l]])
}

#labels of the indiecs - can be useful for plots
.labels=list(
  wiener=expression(W),
  harary=expression(H),
  balabanJ=expression(J),
  meanDistanceDeviation=expression(delta_mu),
  compactness=expression(C),
  productOfRowSums=expression(PRS),
  hyperDistancePathIndex=expression(D[p]),
  totalAdjacency=expression(A),
  zagreb1=expression(Z[1]),
  zagreb2=expression(Z[2]),
  modifiedZagreb=expression(MZI),
  augmentedZagreb=expression(AZI),
  variableZagreb=expression(VZI),
  randic=expression(R),
  complexityIndexB=expression(B),
  normalizedEdgeComplexity=expression(E[N]),
  atomBondConnectivity=expression(ABC),
  geometricArithmetic1=expression(GA1),
  geometricArithmetic2=expression(GA2),
  geometricArithmetic3=expression(GA3),
  narumiKatayama=expression(NK),
  topologicalInfoContent=expression(I[orb]),
  bonchev1=expression(I[D]),
  bonchev2=expression(I[D]^W),
  bertz=expression(C),
  radialCentric=expression(I[C,R]),
  vertexDegree=expression(I[deg]),
  balabanlike1=expression(U),
  balabanlike2=expression(X),
  graphVertexComplexity=expression(I[V]),
  offdiagonal=expression(OdC),
  spanningTreeSensitivity.STS=expression(STS),
  spanningTreeSensitivity.STSD=expression(STSD),
  distanceDegreeCentric=expression(I[C,deg]),
  distanceCodeCentric=expression(I[C,code]),
  infoTheoreticGCM_vertcent_exp.entropy=expression(I[f^C[2],exp]),
  infoTheoreticGCM_vertcent_exp.distance=expression(I[f^C[2],exp]^lambda),
  infoTheoreticGCM_vertcent_lin.entropy=expression(I[f^C[2],lin]),
  infoTheoreticGCM_vertcent_lin.distance=expression(I[f^C[2],lin]^lambda),
  infoTheoreticGCM_sphere_exp.entropy=expression(I[f^V,exp]),
  infoTheoreticGCM_sphere_exp.distance=expression(I[f^V,exp]^lambda),
  infoTheoreticGCM_sphere_lin.entropy=expression(I[f^V,lin]),
  infoTheoreticGCM_sphere_lin.distance=expression(I[f^V,lin]^lambda),
  infoTheoreticGCM_pathlength_exp.entropy=expression(I[f^P[2],exp]),
  infoTheoreticGCM_pathlength_exp.distance=expression(I[f^P[2],exp]^lambda),
  infoTheoreticGCM_pathlength_lin.entropy=expression(I[f^P[2],lin]),
  infoTheoreticGCM_pathlength_lin.distance=expression(I[f^P[2],lin]^lambda),
  infoTheoreticGCM_degree_exp.entropy=expression(I[f^deg,exp]),
  infoTheoreticGCM_degree_exp.distance=expression(I[f^deg,exp]^lambda),
  infoTheoreticGCM_degree_lin.entropy=expression(I[f^deg,lin]),
  infoTheoreticGCM_degree_lin.distance=expression(I[f^deg,lin]^lambda),
  eigenvalueBased_adjacencyMatrix.HMs=expression(H[M[adj],s]),
  eigenvalueBased_adjacencyMatrix.SMs=expression(S[M[adj],s]),
  eigenvalueBased_adjacencyMatrix.ISMs=expression(IS[M[adj],s]),
  eigenvalueBased_adjacencyMatrix.PMs=expression(P[M[adj],s]),
  eigenvalueBased_adjacencyMatrix.IPMs=expression(IP[M[adj],s]),
  eigenvalueBased_adjacencyMatrix_2.HMs=expression(H[M[adj],s,2]),
  eigenvalueBased_adjacencyMatrix_2.SMs=expression(S[M[adj],s,2]),
  eigenvalueBased_adjacencyMatrix_2.ISMs=expression(IS[M[adj],s,2]),
  eigenvalueBased_adjacencyMatrix_2.PMs=expression(P[M[adj],s,2]),
  eigenvalueBased_adjacencyMatrix_2.IPMs=expression(IP[M[adj],s,2]),
  eigenvalueBased_laplaceMatrix.HMs=expression(H[M[lap],s]),
  eigenvalueBased_laplaceMatrix.SMs=expression(S[M[lap],s]),
  eigenvalueBased_laplaceMatrix.ISMs=expression(IS[M[lap],s]),
  eigenvalueBased_laplaceMatrix.PMs=expression(P[M[lap],s]),
  eigenvalueBased_laplaceMatrix.IPMs=expression(IP[M[lap],s]),
  eigenvalueBased_laplaceMatrix_2.HMs=expression(H[M[lap],s,2]),
  eigenvalueBased_laplaceMatrix_2.SMs=expression(S[M[lap],s,2]),
  eigenvalueBased_laplaceMatrix_2.ISMs=expression(IS[M[lap],s,2]),
  eigenvalueBased_laplaceMatrix_2.PMs=expression(P[M[lap],s,2]),
  eigenvalueBased_laplaceMatrix_2.IPMs=expression(IP[M[lap],s,2]),
  eigenvalueBased_augmentedMatrix.HMs=expression(H[M[aug],s]),
  eigenvalueBased_augmentedMatrix.SMs=expression(S[M[aug],s]),
  eigenvalueBased_augmentedMatrix.ISMs=expression(IS[M[aug],s]),
  eigenvalueBased_augmentedMatrix.PMs=expression(P[M[aug],s]),
  eigenvalueBased_augmentedMatrix.IPMs=expression(IP[M[aug],s]),
  eigenvalueBased_augmentedMatrix_2.HMs=expression(H[M[aug],s,2]),
  eigenvalueBased_augmentedMatrix_2.SMs=expression(S[M[aug],s,2]),
  eigenvalueBased_augmentedMatrix_2.ISMs=expression(IS[M[aug],s,2]),
  eigenvalueBased_augmentedMatrix_2.PMs=expression(P[M[aug],s,2]),
  eigenvalueBased_augmentedMatrix_2.IPMs=expression(IP[M[aug],s,2]),
  eigenvalueBased_extendedAdjacencyMatrix.HMs=expression(H[M[ea],s]),
  eigenvalueBased_extendedAdjacencyMatrix.SMs=expression(S[M[ea],s]),
  eigenvalueBased_extendedAdjacencyMatrix.ISMs=expression(IS[M[ea],s]),
  eigenvalueBased_extendedAdjacencyMatrix.PMs=expression(P[M[ea],s]),
  eigenvalueBased_extendedAdjacencyMatrix.IPMs=expression(IP[M[ea],s]),
  eigenvalueBased_extendedAdjacencyMatrix_2.HMs=expression(H[M[ea],s,2]),
  eigenvalueBased_extendedAdjacencyMatrix_2.SMs=expression(S[M[ea],s,2]),
  eigenvalueBased_extendedAdjacencyMatrix_2.ISMs=expression(IS[M[ea],s,2]),
  eigenvalueBased_extendedAdjacencyMatrix_2.PMs=expression(P[M[ea],s,2]),
  eigenvalueBased_extendedAdjacencyMatrix_2.IPMs=expression(IP[M[ea],s,2]),
  eigenvalueBased_vertConnectMatrix.HMs=expression(H[M[con],s]),
  eigenvalueBased_vertConnectMatrix.SMs=expression(S[M[con],s]),
  eigenvalueBased_vertConnectMatrix.ISMs=expression(IS[M[con],s]),
  eigenvalueBased_vertConnectMatrix.PMs=expression(P[M[con],s]),
  eigenvalueBased_vertConnectMatrix.IPMs=expression(IP[M[con],s]),
  eigenvalueBased_vertConnectMatrix_2.HMs=expression(H[M[con],s,2]),
  eigenvalueBased_vertConnectMatrix_2.SMs=expression(S[M[con],s,2]),
  eigenvalueBased_vertConnectMatrix_2.ISMs=expression(IS[M[con],s,2]),
  eigenvalueBased_vertConnectMatrix_2.PMs=expression(P[M[con],s,2]),
  eigenvalueBased_vertConnectMatrix_2.IPMs=expression(IP[M[con],s,2]),
  eigenvalueBased_randomWalkMatrix.HMs=expression(H[M[rw],s]),
  eigenvalueBased_randomWalkMatrix.SMs=expression(S[M[rw],s]),
  eigenvalueBased_randomWalkMatrix.ISMs=expression(IS[M[rw],s]),
  eigenvalueBased_randomWalkMatrix.PMs=expression(P[M[rw],s]),
  eigenvalueBased_randomWalkMatrix.IPMs=expression(IP[M[rw],s]),
  eigenvalueBased_randomWalkMatrix_2.HMs=expression(H[M[rw],s,2]),
  eigenvalueBased_randomWalkMatrix_2.SMs=expression(S[M[rw],s,2]),
  eigenvalueBased_randomWalkMatrix_2.ISMs=expression(IS[M[rw],s,2]),
  eigenvalueBased_randomWalkMatrix_2.PMs=expression(P[M[rw],s,2]),
  eigenvalueBased_randomWalkMatrix_2.IPMs=expression(IP[M[rw],s,2]),
  eigenvalueBased_distanceMatrix.HMs=expression(H[M[dm],s]),
  eigenvalueBased_distanceMatrix.SMs=expression(S[M[dm],s]),
  eigenvalueBased_distanceMatrix.ISMs=expression(IS[M[dm],s]),
  eigenvalueBased_distanceMatrix.PMs=expression(P[M[dm],s]),
  eigenvalueBased_distanceMatrix.IPMs=expression(IP[M[dm],s]),
  eigenvalueBased_distanceMatrix_2.HMs=expression(H[M[dm],s,2]),
  eigenvalueBased_distanceMatrix_2.SMs=expression(S[M[dm],s,2]),
  eigenvalueBased_distanceMatrix_2.ISMs=expression(IS[M[dm],s,2]),
  eigenvalueBased_distanceMatrix_2.PMs=expression(P[M[dm],s,2]),
  eigenvalueBased_distanceMatrix_2.IPMs=expression(IP[M[dm],s,2]),
  eigenvalueBased_distancePathMatrix.HMs=expression(H[M[dpm],s]),
  eigenvalueBased_distancePathMatrix.SMs=expression(S[M[dpm],s]),
  eigenvalueBased_distancePathMatrix.ISMs=expression(IS[M[dpm],s]),
  eigenvalueBased_distancePathMatrix.PMs=expression(P[M[dpm],s]),
  eigenvalueBased_distancePathMatrix.IPMs=expression(IP[M[dpm],s]),
  eigenvalueBased_distancePathMatrix_2.HMs=expression(H[M[dpm],s,2]),
  eigenvalueBased_distancePathMatrix_2.SMs=expression(S[M[dpm],s,2]),
  eigenvalueBased_distancePathMatrix_2.ISMs=expression(IS[M[dpm],s,2]),
  eigenvalueBased_distancePathMatrix_2.PMs=expression(P[M[dpm],s,2]),
  eigenvalueBased_distancePathMatrix_2.IPMs=expression(IP[M[dpm],s,2]),
  eigenvalueBased_weightStrucFuncMatrix_lin.HMs=expression(H[M[IM1],s]),
  eigenvalueBased_weightStrucFuncMatrix_lin.SMs=expression(S[M[IM1],s]),
  eigenvalueBased_weightStrucFuncMatrix_lin.ISMs=expression(IS[M[IM1],s]),
  eigenvalueBased_weightStrucFuncMatrix_lin.PMs=expression(P[M[IM1],s]),
  eigenvalueBased_weightStrucFuncMatrix_lin.IPMs=expression(IP[M[IM1],s]),
  eigenvalueBased_weightStrucFuncMatrix_lin_2.HMs=expression(H[M[IM1],s,2]),
  eigenvalueBased_weightStrucFuncMatrix_lin_2.SMs=expression(S[M[IM1],s,2]),
  eigenvalueBased_weightStrucFuncMatrix_lin_2.ISMs=expression(IS[M[IM1],s,2]),
  eigenvalueBased_weightStrucFuncMatrix_lin_2.PMs=expression(P[M[IM1],s,2]),
  eigenvalueBased_weightStrucFuncMatrix_lin_2.IPMs=expression(IP[M[IM1],s,2]),
  eigenvalueBased_weightStrucFuncMatrix_exp.HMs=expression(H[M[IM2],s]),
  eigenvalueBased_weightStrucFuncMatrix_exp.SMs=expression(S[M[IM2],s]),
  eigenvalueBased_weightStrucFuncMatrix_exp.ISMs=expression(IS[M[IM2],s]),
  eigenvalueBased_weightStrucFuncMatrix_exp.PMs=expression(P[M[IM2],s]),
  eigenvalueBased_weightStrucFuncMatrix_exp.IPMs=expression(IP[M[IM2],s]),
  eigenvalueBased_weightStrucFuncMatrix_exp_2.HMs=expression(H[M[IM2],s,2]),
  eigenvalueBased_weightStrucFuncMatrix_exp_2.SMs=expression(S[M[IM2],s,2]),
  eigenvalueBased_weightStrucFuncMatrix_exp_2.ISMs=expression(IS[M[IM2],s,2]),
  eigenvalueBased_weightStrucFuncMatrix_exp_2.PMs=expression(P[M[IM2],s,2]),
  eigenvalueBased_weightStrucFuncMatrix_exp_2.IPMs=expression(IP[M[IM2],s,2]),
  energy=expression(E),
  laplacianEnergy=expression(LE),
  estrada=expression(EE),
  laplacianEstrada=expression(LEE),
  spectralRadius=expression(SpRad),
  oneEdgeDeletedSubgraphComplexity.C_1eST=expression(C[1,ST]),
  oneEdgeDeletedSubgraphComplexity.C_1eSpec=expression(C[1,Spec]),
  twoEdgesDeletedSubgraphComplexity=expression(C[2,Spec]),
  globalClusteringCoeff=expression(C),
  mediumArticulation=expression(MAg),
  efficiency=expression(Ce),
  graphIndexComplexity=expression(Cr),
  connectivityID=expression(CID),
  minConnectivityID=expression(MINCID),
  primeID=expression(PID),
  bondOrderID=expression(piID),
  balabanID=expression(BID),
  minBalabanID=expression(MINBID),
  weightedID.WID=expression(WID),
  weightedID.SID=expression(SID),
  huXuID=expression(HXID)
)

==> QuACN_1.7.4.tar.gz: QuACN/R/getLabels.R <==
getLabels <- function(l){
  return(.labels[[l]])
}

#labels of the indiecs - can be useful for plots
.labels=list(
  wiener=expression(W),
  harary=expression(H),
  balabanJ=expression(J),
  meanDistanceDeviation=expression(delta_mu),
  compactness=expression(C),
  productOfRowSums=expression(PRS),
  hyperDistancePathIndex=expression(D[p]),
  dobrynin.eccentricityGraph=expression(e),
  dobrynin.avgeccOfG=expression(e[av]),
  dobrynin.ecentricGraph=expression(delta_G),
  dobrynin.graphIntegration=expression(D),
  dobrynin.unipolarity=expression(D^star),
  dobrynin.variation=expression(var),
  dobrynin.centralization=expression(delta_G^star),
  dobrynin.avgDistance=expression(D[av]),
  dobrynin.meanDistVertexDeviation=expression(delta_D),
  totalAdjacency=expression(A),
  zagreb1=expression(Z[1]),
  zagreb2=expression(Z[2]),
  modifiedZagreb=expression(MZI),
  augmentedZagreb=expression(AZI),
  variableZagreb=expression(VZI),
  randic=expression(R),
  complexityIndexB=expression(B),
  normalizedEdgeComplexity=expression(E[N]),
  atomBondConnectivity=expression(ABC),
  geometricArithmetic1=expression(GA1),
  geometricArithmetic2=expression(GA2),
  geometricArithmetic3=expression(GA3),
  narumiKatayama=expression(NK),
  topologicalInfoContent=expression(I[orb]),
  bonchev1=expression(I[D]),
  bonchev2=expression(I[D]^W),
  bonchev3=expression(I[D]^E),
  bertz=expression(C),
  radialCentric=expression(I[C,R]),
  vertexDegree=expression(I[deg]),
  balabanlike1=expression(U),
  balabanlike2=expression(X),
  graphVertexComplexity=expression(I[VC]^v),
  graphDistanceComplexity=expression(I[VC]),
  informationBondIndex=expression(I[B]),
  edgeEqualityMIC=expression(I[chi]^E),
  edgeMagnitudeMIC=expression(I[chi]^M),
  symmetryIndex=expression(S),
  distanceDegreeMIC=expression(I[delta[D]]),
  distanceDegreeEquality=expression(I[D,delta[D]]),
  distanceDegreeCompactness=expression(I[C,delta[D]]),
  informationLayerIndex=expression(I[Sp]),
  offdiagonal=expression(OdC),
  spanningTreeSensitivity.STS=expression(STS),
  spanningTreeSensitivity.STSD=expression(STSD),
  distanceDegreeCentric=expression(I[C,deg]),
  distanceCodeCentric=expression(I[C,code]),
  infoTheoreticGCM_vertcent_exp.entropy=expression(I[f^C[2],exp]),
  infoTheoreticGCM_vertcent_exp.distance=expression(I[f^C[2],exp]^lambda),
  infoTheoreticGCM_vertcent_lin.entropy=expression(I[f^C[2],lin]),
  infoTheoreticGCM_vertcent_lin.distance=expression(I[f^C[2],lin]^lambda),
  infoTheoreticGCM_sphere_exp.entropy=expression(I[f^V,exp]),
  infoTheoreticGCM_sphere_exp.distance=expression(I[f^V,exp]^lambda),
  infoTheoreticGCM_sphere_lin.entropy=expression(I[f^V,lin]),
  infoTheoreticGCM_sphere_lin.distance=expression(I[f^V,lin]^lambda),
  infoTheoreticGCM_pathlength_exp.entropy=expression(I[f^P[2],exp]),
  infoTheoreticGCM_pathlength_exp.distance=expression(I[f^P[2],exp]^lambda),
  infoTheoreticGCM_pathlength_lin.entropy=expression(I[f^P[2],lin]),
  infoTheoreticGCM_pathlength_lin.distance=expression(I[f^P[2],lin]^lambda),
  infoTheoreticGCM_degree_exp.entropy=expression(I[f^deg,exp]),
  infoTheoreticGCM_degree_exp.distance=expression(I[f^deg,exp]^lambda),
  infoTheoreticGCM_degree_lin.entropy=expression(I[f^deg,lin]),
  infoTheoreticGCM_degree_lin.distance=expression(I[f^deg,lin]^lambda),
  infoTheoreticLabeledV1_exp.entropy=expression(I[f^V[1],exp]),
  infoTheoreticLabeledV1_exp.distance=expression(I[f^V[1],exp]^lambda),
  infoTheoreticLabeledV1_lin.entropy=expression(I[f^V[1],lin]),
  infoTheoreticLabeledV1_lin.distance=expression(I[f^V[1],lin]^lambda),
  infoTheoreticLabeledV2.entropy=expression(I[f^V[2]]),
  infoTheoreticLabeledV2.distance=expression(I[f^V[2]]^lambda),
  infoTheoreticLabeledE_exp.entropy=expression(I[f^E,exp]),
  infoTheoreticLabeledE_exp.distance=expression(I[f^E,exp]^lambda),
  infoTheoreticLabeledE_lin.entropy=expression(I[f^E,lin]),
  infoTheoreticLabeledE_lin.distance=expression(I[f^E,lin]^lambda),
  eigenvalueBased_adjacencyMatrix.HMs=expression(H[M[adj],s]),
  eigenvalueBased_adjacencyMatrix.SMs=expression(S[M[adj],s]),
  eigenvalueBased_adjacencyMatrix.ISMs=expression(IS[M[adj],s]),
  eigenvalueBased_adjacencyMatrix.PMs=expression(P[M[adj],s]),
  eigenvalueBased_adjacencyMatrix.IPMs=expression(IP[M[adj],s]),
  eigenvalueBased_adjacencyMatrix_2.HMs=expression(H[M[adj],s,2]),
  eigenvalueBased_adjacencyMatrix_2.SMs=expression(S[M[adj],s,2]),
  eigenvalueBased_adjacencyMatrix_2.ISMs=expression(IS[M[adj],s,2]),
  eigenvalueBased_adjacencyMatrix_2.PMs=expression(P[M[adj],s,2]),
  eigenvalueBased_adjacencyMatrix_2.IPMs=expression(IP[M[adj],s,2]),
  eigenvalueBased_laplaceMatrix.HMs=expression(H[M[lap],s]),
  eigenvalueBased_laplaceMatrix.SMs=expression(S[M[lap],s]),
  eigenvalueBased_laplaceMatrix.ISMs=expression(IS[M[lap],s]),
  eigenvalueBased_laplaceMatrix.PMs=expression(P[M[lap],s]),
  eigenvalueBased_laplaceMatrix.IPMs=expression(IP[M[lap],s]),
  eigenvalueBased_laplaceMatrix_2.HMs=expression(H[M[lap],s,2]),
  eigenvalueBased_laplaceMatrix_2.SMs=expression(S[M[lap],s,2]),
  eigenvalueBased_laplaceMatrix_2.ISMs=expression(IS[M[lap],s,2]),
  eigenvalueBased_laplaceMatrix_2.PMs=expression(P[M[lap],s,2]),
  eigenvalueBased_laplaceMatrix_2.IPMs=expression(IP[M[lap],s,2]),
  eigenvalueBased_augmentedMatrix.HMs=expression(H[M[aug],s]),
  eigenvalueBased_augmentedMatrix.SMs=expression(S[M[aug],s]),
  eigenvalueBased_augmentedMatrix.ISMs=expression(IS[M[aug],s]),
  eigenvalueBased_augmentedMatrix.PMs=expression(P[M[aug],s]),
  eigenvalueBased_augmentedMatrix.IPMs=expression(IP[M[aug],s]),
  eigenvalueBased_augmentedMatrix_2.HMs=expression(H[M[aug],s,2]),
  eigenvalueBased_augmentedMatrix_2.SMs=expression(S[M[aug],s,2]),
  eigenvalueBased_augmentedMatrix_2.ISMs=expression(IS[M[aug],s,2]),
  eigenvalueBased_augmentedMatrix_2.PMs=expression(P[M[aug],s,2]),
  eigenvalueBased_augmentedMatrix_2.IPMs=expression(IP[M[aug],s,2]),
  eigenvalueBased_extendedAdjacencyMatrix.HMs=expression(H[M[ea],s]),
  eigenvalueBased_extendedAdjacencyMatrix.SMs=expression(S[M[ea],s]),
  eigenvalueBased_extendedAdjacencyMatrix.ISMs=expression(IS[M[ea],s]),
  eigenvalueBased_extendedAdjacencyMatrix.PMs=expression(P[M[ea],s]),
  eigenvalueBased_extendedAdjacencyMatrix.IPMs=expression(IP[M[ea],s]),
  eigenvalueBased_extendedAdjacencyMatrix_2.HMs=expression(H[M[ea],s,2]),
  eigenvalueBased_extendedAdjacencyMatrix_2.SMs=expression(S[M[ea],s,2]),
  eigenvalueBased_extendedAdjacencyMatrix_2.ISMs=expression(IS[M[ea],s,2]),
  eigenvalueBased_extendedAdjacencyMatrix_2.PMs=expression(P[M[ea],s,2]),
  eigenvalueBased_extendedAdjacencyMatrix_2.IPMs=expression(IP[M[ea],s,2]),
  eigenvalueBased_vertConnectMatrix.HMs=expression(H[M[con],s]),
  eigenvalueBased_vertConnectMatrix.SMs=expression(S[M[con],s]),
  eigenvalueBased_vertConnectMatrix.ISMs=expression(IS[M[con],s]),
  eigenvalueBased_vertConnectMatrix.PMs=expression(P[M[con],s]),
  eigenvalueBased_vertConnectMatrix.IPMs=expression(IP[M[con],s]),
  eigenvalueBased_vertConnectMatrix_2.HMs=expression(H[M[con],s,2]),
  eigenvalueBased_vertConnectMatrix_2.SMs=expression(S[M[con],s,2]),
  eigenvalueBased_vertConnectMatrix_2.ISMs=expression(IS[M[con],s,2]),
  eigenvalueBased_vertConnectMatrix_2.PMs=expression(P[M[con],s,2]),
  eigenvalueBased_vertConnectMatrix_2.IPMs=expression(IP[M[con],s,2]),
  eigenvalueBased_randomWalkMatrix.HMs=expression(H[M[rw],s]),
  eigenvalueBased_randomWalkMatrix.SMs=expression(S[M[rw],s]),
  eigenvalueBased_randomWalkMatrix.ISMs=expression(IS[M[rw],s]),
  eigenvalueBased_randomWalkMatrix.PMs=expression(P[M[rw],s]),
  eigenvalueBased_randomWalkMatrix.IPMs=expression(IP[M[rw],s]),
  eigenvalueBased_randomWalkMatrix_2.HMs=expression(H[M[rw],s,2]),
  eigenvalueBased_randomWalkMatrix_2.SMs=expression(S[M[rw],s,2]),
  eigenvalueBased_randomWalkMatrix_2.ISMs=expression(IS[M[rw],s,2]),
  eigenvalueBased_randomWalkMatrix_2.PMs=expression(P[M[rw],s,2]),
  eigenvalueBased_randomWalkMatrix_2.IPMs=expression(IP[M[rw],s,2]),
  eigenvalueBased_distanceMatrix.HMs=expression(H[M[dm],s]),
  eigenvalueBased_distanceMatrix.SMs=expression(S[M[dm],s]),
  eigenvalueBased_distanceMatrix.ISMs=expression(IS[M[dm],s]),
  eigenvalueBased_distanceMatrix.PMs=expression(P[M[dm],s]),
  eigenvalueBased_distanceMatrix.IPMs=expression(IP[M[dm],s]),
  eigenvalueBased_distanceMatrix_2.HMs=expression(H[M[dm],s,2]),
  eigenvalueBased_distanceMatrix_2.SMs=expression(S[M[dm],s,2]),
  eigenvalueBased_distanceMatrix_2.ISMs=expression(IS[M[dm],s,2]),
  eigenvalueBased_distanceMatrix_2.PMs=expression(P[M[dm],s,2]),
  eigenvalueBased_distanceMatrix_2.IPMs=expression(IP[M[dm],s,2]),
  eigenvalueBased_distancePathMatrix.HMs=expression(H[M[dpm],s]),
  eigenvalueBased_distancePathMatrix.SMs=expression(S[M[dpm],s]),
  eigenvalueBased_distancePathMatrix.ISMs=expression(IS[M[dpm],s]),
  eigenvalueBased_distancePathMatrix.PMs=expression(P[M[dpm],s]),
  eigenvalueBased_distancePathMatrix.IPMs=expression(IP[M[dpm],s]),
  eigenvalueBased_distancePathMatrix_2.HMs=expression(H[M[dpm],s,2]),
  eigenvalueBased_distancePathMatrix_2.SMs=expression(S[M[dpm],s,2]),
  eigenvalueBased_distancePathMatrix_2.ISMs=expression(IS[M[dpm],s,2]),
  eigenvalueBased_distancePathMatrix_2.PMs=expression(P[M[dpm],s,2]),
  eigenvalueBased_distancePathMatrix_2.IPMs=expression(IP[M[dpm],s,2]),
  eigenvalueBased_weightStrucFuncMatrix_lin.HMs=expression(H[M[IM1],s]),
  eigenvalueBased_weightStrucFuncMatrix_lin.SMs=expression(S[M[IM1],s]),
  eigenvalueBased_weightStrucFuncMatrix_lin.ISMs=expression(IS[M[IM1],s]),
  eigenvalueBased_weightStrucFuncMatrix_lin.PMs=expression(P[M[IM1],s]),
  eigenvalueBased_weightStrucFuncMatrix_lin.IPMs=expression(IP[M[IM1],s]),
  eigenvalueBased_weightStrucFuncMatrix_lin_2.HMs=expression(H[M[IM1],s,2]),
  eigenvalueBased_weightStrucFuncMatrix_lin_2.SMs=expression(S[M[IM1],s,2]),
  eigenvalueBased_weightStrucFuncMatrix_lin_2.ISMs=expression(IS[M[IM1],s,2]),
  eigenvalueBased_weightStrucFuncMatrix_lin_2.PMs=expression(P[M[IM1],s,2]),
  eigenvalueBased_weightStrucFuncMatrix_lin_2.IPMs=expression(IP[M[IM1],s,2]),
  eigenvalueBased_weightStrucFuncMatrix_exp.HMs=expression(H[M[IM2],s]),
  eigenvalueBased_weightStrucFuncMatrix_exp.SMs=expression(S[M[IM2],s]),
  eigenvalueBased_weightStrucFuncMatrix_exp.ISMs=expression(IS[M[IM2],s]),
  eigenvalueBased_weightStrucFuncMatrix_exp.PMs=expression(P[M[IM2],s]),
  eigenvalueBased_weightStrucFuncMatrix_exp.IPMs=expression(IP[M[IM2],s]),
  eigenvalueBased_weightStrucFuncMatrix_exp_2.HMs=expression(H[M[IM2],s,2]),
  eigenvalueBased_weightStrucFuncMatrix_exp_2.SMs=expression(S[M[IM2],s,2]),
  eigenvalueBased_weightStrucFuncMatrix_exp_2.ISMs=expression(IS[M[IM2],s,2]),
  eigenvalueBased_weightStrucFuncMatrix_exp_2.PMs=expression(P[M[IM2],s,2]),
  eigenvalueBased_weightStrucFuncMatrix_exp_2.IPMs=expression(IP[M[IM2],s,2]),
  energy=expression(E),
  laplacianEnergy=expression(LE),
  estrada=expression(EE),
  laplacianEstrada=expression(LEE),
  spectralRadius=expression(SpRad),
  oneEdgeDeletedSubgraphComplexity.C_1eST=expression(C[1,ST]),
  oneEdgeDeletedSubgraphComplexity.C_1eSpec=expression(C[1,Spec]),
  twoEdgesDeletedSubgraphComplexity=expression(C[2,Spec]),
  globalClusteringCoeff=expression(C),
  mediumArticulation=expression(MAg),
  efficiency=expression(Ce),
  graphIndexComplexity=expression(Cr),
  connectivityID=expression(CID),
  minConnectivityID=expression(MINCID),
  primeID=expression(PID),
  bondOrderID=expression(piID),
  balabanID=expression(BID),
  minBalabanID=expression(MINBID),
  weightedID.WID=expression(WID),
  weightedID.SID=expression(SID),
  huXuID=expression(HXID)
)
